@@ -1,18 +1,26 @@
 package HTTP::Engine::Request::Upload;
-use Shika;
-has filename => ();
+use Mouse;
+has filename => (
+    is => 'ro',
+);
 has headers  => (
+    is => 'ro',
     handles => {
         type => 'content_type'
     },
 );
-has size     => ();
-has tempname => ();
+has size     => (
+    is => 'ro',
+);
+has tempname => (
+    is => 'ro',
+);
 has basename => (
+    is => 'ro',
     lazy    => 1,
     default => sub {
         my $self = shift;
-        HTTP::Engine::Util::require_once('File/Spec/Unix.pm');
+        require File::Spec::Unix;
         my $basename = $self->filename;
         $basename =~ s|\\|/|g;
         $basename = ( File::Spec::Unix->splitpath($basename) )[2];
@@ -22,6 +30,7 @@ has basename => (
 );
 
 has fh => (
+    is => 'ro',
     lazy     => 1,
     default  => sub {
         my $self = shift;
@@ -33,7 +42,7 @@ has fh => (
 
 sub copy_to {
     my $self = shift;
-    HTTP::Engine::Util::require_once('File/Copy.pm');
+    require File::Copy;
     File::Copy::copy( $self->tempname, @_ );
 }
 
@@ -59,6 +68,7 @@ sub slurp {
     $content;
 }
 
+no Mouse;
 1;
 __END__
 
