@@ -1,8 +1,7 @@
 package HTTP::Engine::Role::RequestBuilder::ParseEnv;
-use Shika::Role;
+use Mouse::Role;
 
-with {
-    role  => 'HTTP::Engine::Role::RequestBuilder::Standard',
+with 'HTTP::Engine::Role::RequestBuilder::Standard' => {
     alias => { _build_hostname => "_resolve_hostname" }, # we might be able to get it from the env
 };
 
